@@ -99,8 +99,8 @@ mods = ('clu',
         'sys', 'os', 'io', 're', 'abc',
         'argparse', 'collections', 'contextlib', 'copy',
         'datetime', 'functools', 'importlib', 'inspect',
-        'itertools', 'math', 'operator', 'pickle', 'six',
-        'shutil', 'sysconfig', 'weakref',
+        'itertools', 'math', 'operator', 'pathlib',
+        'pickle', 'six', 'shutil', 'sysconfig', 'weakref',
         'numpy', 'more_itertools', 'colorama', 'termcolor',
         'xerox', 'zict', 'pytz', 'dateutil',
         'termplotlib', 'termtables')
@@ -131,6 +131,7 @@ import collections.abc
 from PIL import Image
 from pprint import pprint, pformat
 
+pp = pprint
 ppt = lambda thing: pprint(tuple(thing))
 
 # These two imports trigger module-level __getattr__ actions:
